==> pyloadl-0.2.0.tar.bz2: pyloadl-0.2.0/examples/llbg/bg_partition_query.py <==
from pyloadl import *
from time import gmtime, strftime
from sys import exit

"""


"""


partitionStateString = [ "FREE", "CFG", "READY", "BUSY",
                         "DEALC", "ERROR", "NAV" ]

bg_switch_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

bg_node_mode_t = [ "COPROCESSOR", "VIRTUAL_NODE" ]

bg_connection_t = [ "MESH", "TORUS", "BG_NAV", "PREFER_TORUS" ]

bg_switch_dimension_t = [ "DIM_X", "DIM_Y", "DIM_Z", "DIM_NAV" ]

# Query Blue Gene information

query = ll_query(BLUE_GENE);
if not PyCObjValid(query):
   print "ll_query(): Query Blue Gene returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_BG_PARTITION, ["all"], ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

# Get the machine objects from the LoadL_negotiator (central manager) daemon

machine, obj_count, err_code = ll_get_objs(query, LL_CM, "")
if err_code != 0:
    print "Query MACHINES: ll_get_objs() returns NULL. Error code =  %d" % err_code
    exit(-1)

part_count = ll_get_data(machine, LL_BgMachinePartitionCount)
print "Number Of Partions defined in Blue Gene System = %s" % (part_count)

bp = ll_get_data(machine, LL_BgMachineGetFirstPartition)
while PyCObjValid(bp):
    BP_id = ll_get_data(bp, LL_BgPartitionId)
    print "BG Partition ID : %s" % BP_id
    state = ll_get_data(bp, LL_BgPartitionState)
    print "\tState   : %s" % partitionStateString[state]
    size = ll_get_data(bp, LL_BgPartitionBPCount)
    print "\tBPCount : %s" % size
    sw_count = ll_get_data(bp, LL_BgPartitionSwitchCount)
    print "\tSwitch Count : %s" % sw_count
    connection = ll_get_data(bp, LL_BgPartitionConnection)
    print "\tConnection : %s" % bg_connection_t[connection]
    partition_owner = ll_get_data(bp, LL_BgPartitionOwner)
    print "\tOwner : %s" % partition_owner
    partition_mode = ll_get_data(bp, LL_BgPartitionMode)
    print "\tMode : %s" % bg_node_mode_t[partition_mode]
    partition_small = ll_get_data(bp, LL_BgPartitionSmall)
    if partition_small == 0:
      partition_small = "FALSE"
    else:
      partition_small = "TRUE"
    print "\tSmall : %s" % partition_small

    PartitionMLoaderImage = ll_get_data(bp, LL_BgPartitionMLoaderImage)
    print "\tLoader image file name : %s" % PartitionMLoaderImage
    PartitionBLRTSImage = ll_get_data(bp, LL_BgPartitionBLRTSImage)
    print "\tNode kernel image file name : %s" % PartitionBLRTSImage
    PartitionLinuxImage = ll_get_data(bp, LL_BgPartitionLinuxImage)
    print "\tI/O nodes linux image file name : %s" % PartitionLinuxImage
    PartitionRamDiskImage = ll_get_data(bp, LL_BgPartitionRamDiskImage)
    print "\tRamDisk Image : %s" % PartitionRamDiskImage
    PartitionDescription = ll_get_data(bp, LL_BgPartitionDescription)
    print "\tDescription : %s" % PartitionDescription
    PartitionBPList = ll_get_data(bp, LL_BgPartitionBPList)
    print "\tBPList : %s" % PartitionBPList
    PartitionNCList = ll_get_data(bp, LL_BgPartitionNodeCardList)
    print "\tNCList : %s" % PartitionNCList

    swt = ll_get_data(bp, LL_BgPartitionGetFirstSwitch)
    while PyCObjValid(swt):

       swt_id = ll_get_data(swt, LL_BgSwitchId)
       print "\tBG Partition Switch ID : %s" % swt_id

       swt_bpid = ll_get_data(swt, LL_BgSwitchBasePartitionId)
       print "\t\tSwitch BP ID : %s" % swt_bpid
  
       swt_state = ll_get_data(swt, LL_BgSwitchState)
       print "\t\tSwitch State : %s" % bg_switch_state_t[swt_state]

       swt_dimm = ll_get_data(swt, LL_BgSwitchDimension)
       print "\t\tSwitch Dimm  : %s" % bg_switch_dimension_t[swt_dimm]

       swt_ccount = ll_get_data(swt, LL_BgSwitchConnCount)
       print "\t\tSwitch Conn Count : %s" % swt_ccount

       swt_conn = ll_get_data(swt, LL_BgSwitchGetFirstConn)
       while PyCObjValid(swt_conn):

          pc2swtp = ll_get_data(swt_conn, LL_BgPortConnToSwitchPort)
          pcfswtp = ll_get_data(swt_conn, LL_BgPortConnFromSwitchPort)
          print "\t\t\tConnection: from=%s to=%s" % (pcfswtp, pc2swtp)

          swt_conn = ll_get_data(swt, LL_BgSwitchGetNextConn)

       swt = ll_get_data(bp, LL_BgPartitionGetNextSwitch)

    bp = ll_get_data(machine, LL_BgMachineGetNextPartition)

==> pyloadl-0.4.3.tar.bz2: pyloadl-0.4.3/examples/llbg/bg_partition_query.py <==
from pyloadl import *
from time import gmtime, strftime
from sys import exit

"""

  BlueGene Partition Query

"""


partitionStateString = [ "FREE", "CFG", "READY", "BUSY",
                         "DEALC", "ERROR", "NAV" ]

bg_switch_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

bg_node_mode_t = [ "COPROCESSOR", "VIRTUAL_NODE" ]

bg_connection_t = [ "MESH", "TORUS", "BG_NAV", "PREFER_TORUS" ]

bg_switch_dimension_t = [ "DIM_X", "DIM_Y", "DIM_Z", "DIM_NAV" ]

# Query Blue Gene information

query = ll_query(BLUE_GENE)
if not PyCObjValid(query):
   print "ll_query(): Query Blue Gene returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_BG_PARTITION, ["all"], ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

# Get the machine objects from the LoadL_negotiator (central manager) daemon

machine, obj_count, err_code = ll_get_objs(query, LL_CM, "")
if err_code != 0:
    print "Query MACHINES: ll_get_objs() returns NULL. Error code =  %d" % err_code
    exit(-1)

part_count = ll_get_data(machine, LL_BgMachinePartitionCount)
print "Number Of Partions defined in Blue Gene System = %s" % (part_count)

bp = ll_get_data(machine, LL_BgMachineGetFirstPartition)
while PyCObjValid(bp):
    BP_id = ll_get_data(bp, LL_BgPartitionId)
    print "BG Partition ID : %s" % BP_id
    state = ll_get_data(bp, LL_BgPartitionState)
    print "\tState   : %s" % partitionStateString[state]
    size = ll_get_data(bp, LL_BgPartitionBPCount)
    print "\tBPCount : %s" % size
    sw_count = ll_get_data(bp, LL_BgPartitionSwitchCount)
    print "\tSwitch Count : %s" % sw_count
    connection = ll_get_data(bp, LL_BgPartitionConnection)
    print "\tConnection : %s" % bg_connection_t[connection]
    partition_owner = ll_get_data(bp, LL_BgPartitionOwner)
    print "\tOwner : %s" % partition_owner
    partition_mode = ll_get_data(bp, LL_BgPartitionMode)
    print "\tMode : %s" % bg_node_mode_t[partition_mode]
    partition_small = ll_get_data(bp, LL_BgPartitionSmall)
    if partition_small == 0:
      partition_small = "FALSE"
    else:
      partition_small = "TRUE"
    print "\tSmall : %s" % partition_small

    PartitionMLoaderImage = ll_get_data(bp, LL_BgPartitionMLoaderImage)
    print "\tLoader image file name : %s" % PartitionMLoaderImage
    PartitionBLRTSImage = ll_get_data(bp, LL_BgPartitionBLRTSImage)
    print "\tNode kernel image file name : %s" % PartitionBLRTSImage
    PartitionLinuxImage = ll_get_data(bp, LL_BgPartitionLinuxImage)
    print "\tI/O nodes linux image file name : %s" % PartitionLinuxImage
    PartitionRamDiskImage = ll_get_data(bp, LL_BgPartitionRamDiskImage)
    print "\tRamDisk Image : %s" % PartitionRamDiskImage
    PartitionDescription = ll_get_data(bp, LL_BgPartitionDescription)
    print "\tDescription : %s" % PartitionDescription
    PartitionBPList = ll_get_data(bp, LL_BgPartitionBPList)
    print "\tBPList : %s" % PartitionBPList
    PartitionNCList = ll_get_data(bp, LL_BgPartitionNodeCardList)
    print "\tNCList : %s" % PartitionNCList

    swt = ll_get_data(bp, LL_BgPartitionGetFirstSwitch)
    while PyCObjValid(swt):

       swt_id = ll_get_data(swt, LL_BgSwitchId)
       print "\tBG Partition Switch ID : %s" % swt_id

       swt_bpid = ll_get_data(swt, LL_BgSwitchBasePartitionId)
       print "\t\tSwitch BP ID : %s" % swt_bpid
  
       swt_state = ll_get_data(swt, LL_BgSwitchState)
       print "\t\tSwitch State : %s" % bg_switch_state_t[swt_state]

       swt_dimm = ll_get_data(swt, LL_BgSwitchDimension)
       print "\t\tSwitch Dimm  : %s" % bg_switch_dimension_t[swt_dimm]

       swt_ccount = ll_get_data(swt, LL_BgSwitchConnCount)
       print "\t\tSwitch Conn Count : %s" % swt_ccount

       swt_conn = ll_get_data(swt, LL_BgSwitchGetFirstConn)
       while PyCObjValid(swt_conn):

          pc2swtp = ll_get_data(swt_conn, LL_BgPortConnToSwitchPort)
          pcfswtp = ll_get_data(swt_conn, LL_BgPortConnFromSwitchPort)
          print "\t\t\tConnection: from=%s to=%s" % (pcfswtp, pc2swtp)

          swt_conn = ll_get_data(swt, LL_BgSwitchGetNextConn)

       swt = ll_get_data(bp, LL_BgPartitionGetNextSwitch)

    bp = ll_get_data(machine, LL_BgMachineGetNextPartition)
